@@ -1,11 +1,11 @@
 from pickle import load, dump
+
 from .outputs import *
 
 # FILES HANDLING
 
 def aLoad(fileHandler: dict): # Automatic loading.
 	handler = {}
-	errorHandler = {"type": "error"}
 
 	handler["path"] = ""
 	handler["ignoreMissing"] = False
@@ -18,21 +18,18 @@ def aLoad(fileHandler: dict): # Automatic loading.
 		dataFile.close()
 				
 	except(FileNotFoundError):
-		if not handler["ignoreMissing"]:
-			errorHandler["string"] = "\'" + fileHandler["path"] + "\' NOT FOUND ERROR"
-			output(errorHandler)
 		data = None
+		if not handler["ignoreMissing"]:
+			output({"type": "error", "string": "\'" + fileHandler["path"] + "\' NOT FOUND"})
 
 	except:
-		errorHandler["string"] = "FILE ERROR"
-		output(errorHandler)
 		data = None
+		output({"type": "error", "string": "FILE ERROR"})
 
 	return data
 	
 def aDump(fileHandler: dict) -> None: # Automatic dumping.
 	handler = {}
-	errorHandler = {"type": "error"}
 
 	handler["path"] = ""
 	handler["data"] = None
@@ -45,5 +42,4 @@ def aDump(fileHandler: dict) -> None: # Automatic dumping.
 		dataFile.close()
 	
 	except:
-		errorHandler["string"] = "FILE ERROR"
-		output(errorHandler)
\ No newline at end of file
+		output({"type": "error", "string": "FILE ERROR"})
\ No newline at end of file
